You've been added to the organization {{ organization|safe }} on {{ domain.name }} by {{ sender.full_name|safe }}.`

Follow the link below to view this organization.

http://{{ domain.domain }}{% url "organization_detail" organization.pk %}

If you are unsure about this link please contact the sender.
